@@ -10,6 +10,8 @@ from .git import git
 from .pyon2json import pyon2json
 from .csplit import csplit
 from .cpush import cpush
+from .pqcat import pqcat
+from .csv2tex import csv2tex
 
 # from .rm_timestamped import rm_timestamped
 from .obscure import obscure, unobscure
@@ -33,6 +35,8 @@ cli.add_command(cpush)
 cli.add_command(obscure)
 cli.add_command(unobscure)
 cli.add_command(mail)
+cli.add_command(pqcat)
+cli.add_command(csv2tex)
 
 if __name__ == "__main__":
     cli(prog_name="pb")
