@@ -1,7 +1,9 @@
 """Start a ssh based socks proxy using autossh."""
 
+import shlex
+
 import click
-from subprocess import run
+from subprocess import run, CalledProcessError
 
 
 @click.command()
@@ -14,25 +16,27 @@ def proxy(port, verbose, host):
     """Start a ssh proxy on local port to remove host."""
     click.secho(f"Starting proxy to {host} on port {port}", fg="green")
 
-    # fmt: off
-    options = [
-        "-M", "0",
-        "-o", "ServerAliveInterval 10",
-        "-o", "ServerAliveCountMax 3",
-        "-o", "ExitOnForwardFailure=yes",
-        "-N",
-        "-S", "none",
-        "-D",
-        f"127.0.0.1:{port}",
-    ]
-    # fmt: on
+    options = f"""
+        -M 0
+        -S none
+        -o ServerAliveInterval=10
+        -o ServerAliveCountMax=3
+        -o ExitOnForwardFailure=yes
+        -o BatchMode=yes
+        -N
+        -D
+        127.0.0.1:{port}
+        """
+    options = shlex.split(options)
 
     for _ in range(verbose):
         options.append("-v")
 
     cmd = ["autossh"] + options + [host]
-    run(cmd, check=True)
-
+    try:
+        run(cmd, check=True)
+    except CalledProcessError as e:
+        click.secho(f"Proxy command failed\n{e}", fg="red")
 
 if __name__ == "__main__":
     proxy()
